/*
 * ThreadData.java
 * Created on 2012/05/24
 *
 * Copyright (C) 2011-2013 Nippon Telegraph and Telephone Corporation
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */
package jp.co.ntt.oss.heapstats.container;

import java.io.Serializable;

/**
 * implements {@link Serializable}<br>
 * <br>
 * Contains information about the thread.
 */
public class ThreadData implements
                       Serializable {
    /** serialVersionUID. */
    private static final long serialVersionUID = 3795657965056209363L;

    /** Class name. */
    private String className;

    /** Method name. */
    private String methodName;

    /** thread name. */
    private String threadName;

    /** Waiting to lock object has been retrieved. */
    private String waitLock;

    /** Thread that owns the lock object has been waiting for acquisition. */
    private String waitThread;

    /** lock object or thread name. */
    private String lockThread;

    /**
     * Create a ThreadData.
     */
    public ThreadData() {
        className = "";
        threadName = "";
        waitLock = "";
        waitThread = "";
        lockThread = "";
    }

    /**
     * Return the Class Name.
     *
     * @return Return the Class Name
     */
    public final String getClassName() {
        return className;
    }

    /**
     * Sets the Class Name.
     *
     * @param value Sets the Class Name
     */
    public final void setClassName(final String value) {
        this.className = value;
    }

    /**
     * Return the Method Name.
     *
     * @return Return the Method Name
     */
    public final String getMethodName() {
        return methodName;
    }

    /**
     * Sets the Method Name
     *
     * @param value Sets the Method Name
     */
    public final void setMethodName(String value) {
        this.methodName = value;
    }

    /**
     * Return the thread name.
     *
     * @return Return the thread name
     */
    public final String getThreadName() {
        return threadName;
    }

    /**
     * Sets the thread name.
     *
     * @param value Sets the thread name
     */
    public final void setThreadName(final String value) {
        this.threadName = value;
    }

    /**
     * Return the wait lock object.
     *
     * @return Return the wait lock object
     */
    public final String getWaitLock() {
        return waitLock;
    }

    /**
     * Sets the wait lock object.
     *
     * @param value Sets the wait lock object
     */
    public final void setWaitLock(final String value) {
        this.waitLock = value;
    }

    /**
     * Return the wait thread name.
     *
     * @return Return the wait thread name
     */
    public final String getWaitThread() {
        return waitThread;
    }

    /**
     * Sets the wait thread name.
     *
     * @param value Sets the wait thread name
     */
    public final void setWaitThread(final String value) {
        this.waitThread = value;
    }

    /**
     * Return the lock thread name or lock object.
     *
     * @return Return the lock thread name or lock object
     */
    public final String getLockThread() {
        return lockThread;
    }

    /**
     * Sets the lock thread name or lock object.
     *
     * @param value Sets the lock thread name or lock object
     */
    public final void setLockThread(final String value) {
        this.lockThread = value;
    }
}
